@@ -1,22 +1,27 @@
 #' ANOVA for lm.rrpp model fits
 #'
-#' @description Computes an analysis of variance (ANOVA) table using distributions of random
-#' statistics from \code{\link{lm.rrpp}}.  ANOVA can be performed on one model or multiple models.  
-#' If the latter, the first model is considered a null model for comparison to other models.  The ANOVA is 
-#' functionally similar to a non-parametric likelihood ratio test for all null-full model comparisons
-#' Residuals from the null model will be used to generate random pseudovalues via RRPP for evaluation of subsequent models.
-#' The permutation schedule from the null model will be used for random permutations.
-#' This function does not correct for improper null models.  One must assure that the null model is nested
-#' within the other models.  Illogical results can be generated if this is not the case.
+#' @description Computes an analysis of variance (ANOVA) table using 
+#' distributions of random statistics from \code{\link{lm.rrpp}}.  
+#' ANOVA can be performed on one model or multiple models.  
+#' If the latter, the first model is considered a null model for 
+#' comparison to other models.  The ANOVA is functionally similar to a 
+#' non-parametric likelihood ratio test for all null-full model comparisons
+#' Residuals from the null model will be used to generate random pseudo-values 
+#' via RRPP for evaluation of subsequent models. The permutation schedule from 
+#' the null model will be used for random permutations.
+#' This function does not correct for improper null models.  One must assure 
+#' that the null model is nested within the other models.  Illogical results 
+#' can be generated if this is not the case.
 #'
 #' @param object Object from \code{\link{lm.rrpp}}
 #' @param ... Additional lm.rrpp model fits or other arguments passed to anova. 
-#' @param effect.type One of "F", "cohenf", "SS", "MS", "Rsq" to choose from which distribution
-#' of statistics to calculate effect sizes (Z).  See \code{\link{lm.rrpp}}.
-#' @param error An optional character string to define MS error term for calculation of F values.
-#' See \code{\link{lm.rrpp}} for examples.
-#' @param print.progress A logical argument if multiple models are used and one wishes to view progress
-#' for sums of squares (SS) calculations.
+#' @param effect.type One of "F", "cohenf", "SS", "MS", "Rsq" to choose from 
+#' which distribution of statistics to calculate effect sizes (Z).  
+#' See \code{\link{lm.rrpp}}.
+#' @param error An optional character string to define MS error term for 
+#' calculation of F values. See \code{\link{lm.rrpp}} for examples.
+#' @param print.progress A logical argument if multiple models are used and 
+#' one wishes to view progress for sums of squares (SS) calculations.
 #' @export anova.lm.rrpp
 #' @export
 #' @author Michael Collyer
@@ -31,8 +36,8 @@
 #'
 #'# Single-Model ANOVA
 #'
-#' # Note: one should increase RRPP iterations but a smaller number is used here for demonstration 
-#' # efficiency.  Generally, iter = 999 will take less
+#' # Note: one should increase RRPP iterations but a smaller number is used 
+#' # here for demonstration efficiency.  Generally, iter = 999 will take less
 #' # than 1s for this example with a modern computer.
 #' 
 #' fit <- lm.rrpp(coords ~ logSize + Sex*Pop, SS.type = "I", 
@@ -62,7 +67,8 @@ anova.lm.rrpp <- function(object, ...,
   if(any(lm.check)) {
     lm.list <- dots[lm.check]
     out <- aov.multi.model(object, lm.list, 
-                           effect.type = effect.type, print.progress = print.progress)
+                           effect.type = effect.type, 
+                           print.progress = print.progress)
   } else out <- aov.single.model(object, ...,
                           effect.type = effect.type,
                           error = error)
